@@ -14,8 +14,8 @@ class ScreenshotService(object):
 
         dl_message_version_exchange = self.service.recv_plist()
         version_major = dl_message_version_exchange[1]
-        self.service.send_plist(['DLMessageVersionExchange', 'DLVersionsOk', version_major])
-        dl_message_device_ready = self.service.recv_plist()
+        dl_message_device_ready = self.service.send_recv_plist(
+            ['DLMessageVersionExchange', 'DLVersionsOk', version_major])
         if dl_message_device_ready[0] != 'DLMessageDeviceReady':
             raise PyMobileDevice3Exception('Screenshotr didn\'t return ready state')
 
